<?php

/**
 * @file
 * Commerce free shipping admininistration settings form.
 */

/**
 * Form constructor for Free shipping settings.
 */
function commerce_free_shipping_admin_form($form, &$form_state) {
  $form = system_settings_form($form);

  $shipping_services = commerce_shipping_services();
  foreach ($shipping_services as $service) {
    $base = $service['base'];
    $form[$base] = array(
      '#title' => t('Service') . ' : ' . $base,
      '#type' => 'fieldset',
      '#collapsed' => variable_get($base . '_free_shipping_enabled', FALSE) ? FALSE : TRUE,
      '#collapsible' => TRUE,
    );
    $form[$base][$base . '_free_shipping_enabled'] = array(
      '#title' => t('Enable/Disable Free shipping.'),
      '#type' => 'checkbox',
      '#default_value' => variable_get($base . '_free_shipping_enabled', FALSE),
    );

    $default_currency = variable_get($base . '_free_shipping_rate_limit_currency', 'default');
    if ($default_currency == 'default') {
      $default_currency = commerce_default_currency();
    }
    $currency = commerce_currency_load($default_currency);
    // Convert the price amount to a user friendly decimal value.
    $default_amount = commerce_currency_amount_to_decimal(variable_get($base . '_free_shipping_rate_limit', 6000), $currency['code']);

    // Run it through number_format() to ensure it has the proper number of
    // decimal places.
    $default_amount = number_format($default_amount, $currency['decimals'], '.', '');
    $form[$base]['price'] = array(
      '#type' => 'fieldset',
      '#title' => 'Price threshold',
    );
    $form[$base]['price'][$base . '_free_shipping_rate_limit'] = array(
      '#title' => t('Price threshold to obtain free shipping'),
      '#type' => 'textfield',
      '#size' => 10,
      '#default_value' => $default_amount,
      '#required' => TRUE,
    );

    // Build an options array of allowed currency values including the option
    // for the widget to always use the store's default currency.
    $options = array(
      'default' => t('- Default store currency -'),
    );
    foreach (commerce_currencies(TRUE) as $currency_code => $currency) {
      $options[$currency_code] = t('@code - @name', array('@code' => $currency['code'], '@name' => $currency['name']));
    }
    $form[$base]['price'][$base . '_free_shipping_rate_limit_currency'] = array(
      '#type' => 'select',
      '#title' => t('Currency'),
      '#options' => $options,
      '#default_value' => $default_currency,
    );

    // Messages settings:
    $form[$base][$base . '_free_shipping_gift_message_display'] = array(
      '#title' => t('Display a message when the user get free shipping price.'),
      '#type' => 'checkbox',
      '#default_value' => variable_get($base . '_free_shipping_gift_message_display', TRUE),
    );
    $form[$base][$base . '_free_shipping_gift_message'] = array(
      '#title' => t('Message to display on the checkout shipping service panes when the customer obtain the free shipping.'),
      '#description' => t('%rate will be replaced by the limit price to obtain free shipping'),
      '#type' => 'textfield',
      '#default_value' => variable_get($base . '_free_shipping_gift_message', 'You have got free pricing on ' . $service['display_title'] . ', because your order total has raise %rate !'),
    );
    $form[$base][$base . '_free_shipping_reject_message_display'] = array(
      '#title' => t("Display a message when the user don't get free shipping price."),
      '#type' => 'checkbox',
      '#default_value' => variable_get($base . '_free_shipping_reject_message_display', TRUE),
    );
    $form[$base][$base . '_free_shipping_reject_message'] = array(
      '#title' => t("Message to display on the checkout shipping service panes when the customer doesn't obtain the free shipping."),
      '#description' => t('%rate will be replaced by the price left to obtain a free shipping'),
      '#type' => 'textfield',
      '#default_value' => variable_get($base . '_free_shipping_reject_message', '%rate left to get free pricing on ' . $service['display_title']),
    );
  }
  $form['#validate'][] = 'commerce_free_shipping_admin_form_validate';
  return $form;
}

/**
 * Validate callback: ensures the amount value is numeric and converts it from a
 * decimal value to an integer price amount.
 */
function commerce_free_shipping_admin_form_validate($form, &$form_state) {
  $shipping_services = commerce_shipping_services();
  foreach ($shipping_services as $service) {
    $base = $service['base'];

    if ($form[$base]['price'][$base . '_free_shipping_rate_limit']['#value'] !== '') {
      if ($form[$base]['price'][$base . '_free_shipping_rate_limit_currency']['#value'] == 'default') {
        $currency = commerce_default_currency();
      }
      else {
        $currency = $form[$base]['price'][$base . '_free_shipping_rate_limit_currency']['#value'];
      }
      // Ensure the price is numeric.
      if (!is_numeric($form[$base]['price'][$base . '_free_shipping_rate_limit']['#value'])) {
        form_error($form[$base]['price'][$base . '_free_shipping_rate_limit'], t('%title: you must enter a numeric value for the price amount.', array('%title' => $form[$base]['price'][$base . '_free_shipping_rate_limit']['#title'])));
      }
      else {
        // Convert the decimal amount value entered to an integer based amount value.
        form_set_value($form[$base]['price'][$base . '_free_shipping_rate_limit'], commerce_currency_decimal_to_amount($form[$base]['price'][$base . '_free_shipping_rate_limit']['#value'], $currency), $form_state);
      }
    }
  }
}
